Module: Kernel
- Defined in:
- lib/minestrone/configuration/namespaces.rb
Class Method Summary collapse
-
.method_added(name) ⇒ Object
Detect method additions to Kernel and remove them in the Namespace class.
- .method_added_without_minestrone ⇒ Object
Class Method Details
.method_added(name) ⇒ Object
Detect method additions to Kernel and remove them in the Namespace class
212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/minestrone/configuration/namespaces.rb', line 212 def method_added(name) result = method_added_without_minestrone(name) return result if self != Kernel namespace = Minestrone::Configuration::Namespaces::Namespace if namespace.method_defined?(name) && namespace.instance_method(name).owner == Kernel namespace.send :undef_method, name end result end |
.method_added_without_minestrone ⇒ Object
208 |
# File 'lib/minestrone/configuration/namespaces.rb', line 208 alias_method :method_added_without_minestrone, :method_added |