Class: Minestrone::Deploy::Strategy::Copy

Inherits:
Base
  • Object
show all
Defined in:
lib/minestrone/recipes/deploy/strategy/copy.rb

Overview

This class implements the strategy for deployments which work by preparing the source code locally, compressing it, copying the file to the target host, and uncompressing it to the deployment directory.

By default, the SCM checkout command is used to obtain the local copy of the source code. If you would rather use the export operation, you can set the :copy_strategy variable to :export.

set :copy_strategy, :export

For even faster deployments, you can set the :copy_cache variable to true. This will cause deployments to do a new checkout of your repository to a new directory, and then copy that checkout. Subsequent deploys will just resync that copy, rather than doing an entirely new checkout. Additionally, you can specify file patterns to exclude from the copy when using :copy_cache; just set the :copy_exclude variable to a file glob (or an array of globs).

set :copy_cache, true
set :copy_exclude, ".git/*"

Note that :copy_strategy is ignored when :copy_cache is set. Also, if you want the copy cache put somewhere specific, you can set the variable to the path you want, instead of merely ‘true’:

set :copy_cache, "/tmp/caches/myapp"

This deployment strategy also supports a special variable, :copy_compression, which must be one of :gzip, :bz2, or :zip, and which specifies how the source should be compressed for transmission to each host.

By default, files will be transferred across to the remote machines via ‘sftp’. If you prefer to use ‘scp’ you can set the :copy_via variable to :scp.

set :copy_via, :scp

There is a possibility to pass a build command that will get executed if your code needs to be compiled or something needs to be done before the code is ready to run.

set :build_script, "make all"

Note that if you use :copy_cache, the :build_script is used on the cache and thus you get faster compilation if your script does not recompile everything.

Defined Under Namespace

Classes: Compression

Instance Attribute Summary

Attributes inherited from Base

#configuration

Instance Method Summary collapse

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Minestrone::Deploy::Strategy::Base

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Minestrone::Deploy::Strategy::Base

Instance Method Details

#build(directory) ⇒ Object



75
76
77
78
79
80
81
# File 'lib/minestrone/recipes/deploy/strategy/copy.rb', line 75

def build(directory)
  return unless build_script

  execute "running build script on #{directory}" do
    Dir.chdir(directory) { system(build_script) }
  end 
end

#check!Object



83
84
85
86
87
88
89
# File 'lib/minestrone/recipes/deploy/strategy/copy.rb', line 83

def check!
  super.check do |d|
    d.local.command(source.local.command) if source.local.command
    d.local.command(compress(nil, nil).first)
    d.remote.command(decompress(nil).first)
  end
end

#copy_cacheObject

Returns the location of the local copy cache, if the strategy should use a local cache + copy instead of a new checkout/export every time. Returns nil unless :copy_cache has been set. If :copy_cache is true, a default cache location will be returned.



96
97
98
99
100
101
102
103
104
# File 'lib/minestrone/recipes/deploy/strategy/copy.rb', line 96

def copy_cache
  @copy_cache ||= if configuration[:copy_cache] == true
    File.expand_path(configuration[:application], Dir.tmpdir)
  else
    File.expand_path(configuration[:copy_cache], Dir.pwd)
  end
rescue StandardError
  nil
end

#deploy!Object

Obtains a copy of the source code locally (via the #command method), compresses it to a single file, copies that file to the target server, and uncompresses it into the deployment directory.



65
66
67
68
69
70
71
72
73
# File 'lib/minestrone/recipes/deploy/strategy/copy.rb', line 65

def deploy!
  copy_cache ? run_copy_cache_strategy : run_copy_strategy

  create_revision_file
  compress_repository
  distribute!
ensure
  rollback_changes
end