Class: Minestrone::Logger

Inherits:
Object
  • Object
show all
Defined in:
lib/minestrone/logger.rb

Overview

:nodoc:

Constant Summary collapse

IMPORTANT =
0
INFO =
1
DEBUG =
2
TRACE =
3
MAX_LEVEL =
3
COLORS =
{
  :none     => "0",
  :black    => "30",
  :red      => "31",
  :green    => "32",
  :yellow   => "33",
  :blue     => "34",
  :magenta  => "35",
  :cyan     => "36",
  :white    => "37"
}
STYLES =
{
  :bright     => 1,
  :dim        => 2,
  :underscore => 4,
  :blink      => 5,
  :reverse    => 7,
  :hidden     => 8
}

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ Logger

Returns a new instance of Logger.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/minestrone/logger.rb', line 80

def initialize(options = {})
  output = options[:output] || $stderr

  if output.respond_to?(:puts)
    @device = output
  else
    @device = File.open(output.to_str, "a")
    @needs_close = true
  end

  @options = options
  @level = options[:level] || 0
  @disable_formatters = options[:disable_formatters]
end

Instance Attribute Details

#deviceObject

Returns the value of attribute device.



5
6
7
# File 'lib/minestrone/logger.rb', line 5

def device
  @device
end

#disable_formattersObject

Returns the value of attribute disable_formatters.



5
6
7
# File 'lib/minestrone/logger.rb', line 5

def disable_formatters
  @disable_formatters
end

#levelObject

Returns the value of attribute level.



5
6
7
# File 'lib/minestrone/logger.rb', line 5

def level
  @level
end

Class Method Details

.add_formatter(options) ⇒ Object

:nodoc:



69
70
71
72
# File 'lib/minestrone/logger.rb', line 69

def add_formatter(options) #:nodoc:
  @formatters.push(options)
  @sorted_formatters = nil
end

.default_formattersObject



57
58
59
# File 'lib/minestrone/logger.rb', line 57

def default_formatters
  @default_formatters
end

.default_formatters=(defaults = nil) ⇒ Object



61
62
63
64
65
66
67
# File 'lib/minestrone/logger.rb', line 61

def default_formatters=(defaults = nil)
  @default_formatters = [defaults].flatten

  # reset the formatters
  @formatters = @default_formatters
  @sorted_formatters = nil
end

.sorted_formattersObject



74
75
76
77
# File 'lib/minestrone/logger.rb', line 74

def sorted_formatters
  # Sort matchers in reverse order so we can break if we found a match.
  @sorted_formatters ||= @formatters.sort_by { |i| -(i[:priority] || i[:prio] || 0) }
end

Instance Method Details

#closeObject



95
96
97
# File 'lib/minestrone/logger.rb', line 95

def close
  device.close if @needs_close
end

#debug(message, line_prefix = nil) ⇒ Object



158
159
160
# File 'lib/minestrone/logger.rb', line 158

def debug(message, line_prefix = nil)
  log(DEBUG, message, line_prefix)
end

#format(message, color, style, nl = "\n") ⇒ Object



166
167
168
169
# File 'lib/minestrone/logger.rb', line 166

def format(message, color, style, nl = "\n")
  style = "#{style};" if style
  "\e[#{style}#{color}m" + message.to_s.strip + "\e[0m#{nl}"
end

#important(message, line_prefix = nil) ⇒ Object



150
151
152
# File 'lib/minestrone/logger.rb', line 150

def important(message, line_prefix = nil)
  log(IMPORTANT, message, line_prefix)
end

#info(message, line_prefix = nil) ⇒ Object



154
155
156
# File 'lib/minestrone/logger.rb', line 154

def info(message, line_prefix = nil)
  log(INFO, message, line_prefix)
end

#log(level, message, line_prefix = nil) ⇒ Object



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/minestrone/logger.rb', line 99

def log(level, message, line_prefix = nil)
  if level <= self.level

    # Only format output if device is a TTY and formatters are not disabled
    if device.tty? && !@disable_formatters
      color = :none
      style = nil

      Logger.sorted_formatters.each do |formatter|
        if (formatter[:level] == level || formatter[:level].nil?)
          if message =~ formatter[:match] || formatter[:match] =~ line_prefix.to_s
            color = formatter[:color] if formatter[:color]
            style = formatter[:style] || formatter[:attribute] # (support original cap colors)
            message.gsub!(formatter[:match], formatter[:replace]) if formatter[:replace]
            message = formatter[:prepend] + message unless formatter[:prepend].nil?
            message = message + formatter[:append] unless formatter[:append].nil?
            message = Time.now.strftime('%Y-%m-%d %T') + ' ' + message if formatter[:timestamp]
            break unless formatter[:replace]
          end
        end
      end

      if color == :hide
        # Don't do anything if color is set to :hide
        return false
      end

      term_color = COLORS[color]
      term_style = STYLES[style]

      # Don't format message if no color or style
      unless color == :none and style.nil?
        unless line_prefix.nil?
          line_prefix = format(line_prefix, term_color, term_style, nil)
        end
        message = format(message, term_color, term_style)
      end
    end

    indent = "%*s" % [MAX_LEVEL, "*" * (MAX_LEVEL - level)]

    message.lines.each do |line|
      if line_prefix
        device.puts "#{indent} [#{line_prefix}] #{line.strip}\n"
      else
        device.puts "#{indent} #{line.strip}\n"
      end
    end
  end
end

#trace(message, line_prefix = nil) ⇒ Object



162
163
164
# File 'lib/minestrone/logger.rb', line 162

def trace(message, line_prefix = nil)
  log(TRACE, message, line_prefix)
end